@@ -38,10 +38,10 @@ class LogViewWidget : public QTreeWidget
     Q_OBJECT
 
 public:
-    LogViewWidget(QWidget *parent = NULL);
+    explicit LogViewWidget(QWidget *parent = nullptr);
 
-    virtual ~LogViewWidget();
-    void selectAll() Q_DECL_OVERRIDE;
+    ~LogViewWidget() override;
+    void selectAll() override;
     void setColumns(const LogViewColumns &columns);
 
     int itemCount() const;
@@ -70,13 +70,13 @@ public:
 
     void resizeColumns();
 
-public slots:
+public Q_SLOTS:
     void toggleToolTip(bool enabled);
 
-signals:
+Q_SIGNALS:
     void columnsChanged(const LogViewColumns &columns);
 
-private slots:
+private Q_SLOTS:
     void toggleHeader(QAction *action);
 
 private:
